==> qmmp-plugin-pack-0.12.2.tar.bz2: qmmp-plugin-pack-0.12.2/src/Engines/ffvideo/translations/ffvideo_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Плагін відео FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Файли відео</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="165"/>
        <source>About FFVideo Plugin</source>
        <translation>Про плагін відео FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="166"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Плагін відео на базі FFmpeg для Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Compiled against:</source>
        <translation>Зібрано з:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="177"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Розмір файла</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Бітрейт звуку</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Частота дискретизації звуку</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>КіБ</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>кб/с</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Аудіоканали</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Розмір відео</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Бітрейт відео</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Відео FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Пробіл</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Стоп</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Повноекранний режим</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.4.0.tar.bz2: qmmp-plugin-pack-1.4.0/src/Engines/ffvideo/translations/ffvideo_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Плагін відео FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Файли відео</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="165"/>
        <source>About FFVideo Plugin</source>
        <translation>Про плагін відео FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="166"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Плагін відео на базі FFmpeg для Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Compiled against:</source>
        <translation>Зібрано з:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="177"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Розмір файла</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Бітрейт звуку</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Частота дискретизації звуку</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>КіБ</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>кбіт/с</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Аудіоканали</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Розмір відео</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Бітрейт відео</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Відео FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Пробіл</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Стоп</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Повноекранний режим</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
</TS>
